@@ -826,8 +826,20 @@ def configure_model(args):
             private_out.append([item[0], elements])
 
         private_json_path = os.path.join(pkg_dir, "private.json")
-        generalkey(private_json_path, private_out,
-                   verbose=True, ask=not YES)
+
+        cache_dir = utils.create_package_cache_dir(model)
+
+        cache = os.path.join(cache_dir, "private.json")
+
+        # First run ml configure, Create private.json in cache
+        if not os.path.exists(cache):
+            generalkey(cache, private_out,
+                       verbose=True, ask=not YES)
+            utils.make_symlink(cache, private_json_path)
+        else:
+            utils.make_symlink(cache, private_json_path)
+            generalkey(private_json_path, private_out,
+                       verbose=True, ask=not YES)
 
     depspec = None
     if "dependencies" in entry:
